==> neuro-0.2.2.tar.gz: lib/neuro.dart <==
library neuro;

class Neuro {
  List<Handler> _handlers = [];
  List _variables = [];
  bool debug = false;

  void emit<T>([var value]) {
    print("neuro.emit(value: $value)");

    int handlersFound = 0;

    for(int i =0; i < _handlers.length; i++){

      Handler handler = _handlers[i];

      if (!handler.enabled) return;

      if (value != null && !handler.canHandle(value)) return;

      if (value == null && !handler.canHandleType<T>()) return;

      handlersFound++;

      Future futureResult = handler.handle(value).catchError((error) {
        emit(error);
        return null;
      });

      if (futureResult == null) {
        return;
      }

      futureResult.then((output) {
        if (output != null) {

          if (handler.canHandle(output)) {
            handler.enabled = false;
            print("handler disabled because it returns own handle type");
          } else {
            emit(output);
          }
        }
      });
    }

    if(handlersFound == 0){
      print("Warning no handlers found for $value");
    }else{
      print("DEBUG, value: $value, handlers: $handlersFound");
    }
  }

  void logHandlers(){
    print("----- neuro.logHandlers() ------");
    print("Total Handlers ${_handlers.length}");
    for(int i = 0; i < _handlers.length; i++){
      print("handler $i: ${_handlers[i]}");
    }
    print("----- end log ------");
  }

  void add(var variable){
    _variables.add(variable);
  }

  T get<T>(){
    return _variables.firstWhere((element) => element is T, orElse: (){
      return null;
    });
  }

  void handle<T>(HandlerFunction<T> _handlerFunction) {
    print("neuro.handle($_handlerFunction)");
    _handlers.add(Handler<T>(_handlerFunction));
  }


  void clear() {
    print("neuro.reset()");
    _handlers.clear();
  }
}

class Handler<T> {
  HandlerFunction<T> _handlerFunction;

  Handler(this._handlerFunction);

  bool enabled = true;

  Future handle(var value) async {
    return await _handlerFunction(value);
  }

  bool canHandle(var value) {
    return value is T;
  }

  bool canHandleType<J>() {
    return J == T;
  }

  void printType(){
    print("Handler: $T");
  }
}

typedef Future<dynamic> HandlerFunction<E>(E element);

==> neuro-0.2.3.tar.gz: lib/neuro.dart <==
library neuro;

class Neuro {
  List<Handler> _handlers = [];
  List _variables = [];
  bool debug = false;

  void emit<T>([var value]) {
    print("neuro.emit(value: $value)");

    int handlersFound = 0;

    for(int i =0; i < _handlers.length; i++){

      if (!_handlers[i].enabled) return;

      if (value != null && !_handlers[i].canHandle(value)) return;

      if (value == null && !_handlers[i].canHandleType<T>()) return;

      handlersFound++;

      Future futureResult = _handlers[i].handle(value).catchError((error) {
        emit(error);
        return null;
      });

      if (futureResult == null) {
        return;
      }

      futureResult.then((output) {
        if (output != null) {

          if (_handlers[i].canHandle(output)) {
            _handlers[i].enabled = false;
            print("handler disabled because it returns own handle type");
          } else {
            emit(output);
          }
        }
      });
    }

    if(handlersFound == 0){
      print("Warning no handlers found for $value");
    }else{
      print("DEBUG, value: $value, handlers: $handlersFound");
    }
  }

  void logHandlers(){
    print("----- neuro.logHandlers() ------");
    print("Total Handlers ${_handlers.length}");
    for(int i = 0; i < _handlers.length; i++){
      print("handler $i: ${_handlers[i]}");
    }
    print("----- end log ------");
  }

  void add(var variable){
    _variables.add(variable);
  }

  T get<T>(){
    return _variables.firstWhere((element) => element is T, orElse: (){
      return null;
    });
  }

  void handle<T>(HandlerFunction<T> _handlerFunction) {
    print("neuro.handle($_handlerFunction)");
    _handlers.add(Handler<T>(_handlerFunction));
  }


  void clear() {
    print("neuro.reset()");
    _handlers.clear();
  }
}

class Handler<T> {
  HandlerFunction<T> _handlerFunction;

  Handler(this._handlerFunction);

  bool enabled = true;

  Future handle(var value) async {
    return await _handlerFunction(value);
  }

  bool canHandle(var value) {
    return value is T;
  }

  bool canHandleType<J>() {
    return J == T;
  }

  void printType(){
    print("Handler: $T");
  }
}

typedef Future<dynamic> HandlerFunction<E>(E element);
